package javax.swing.tree;

import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.BitSet;
import java.util.Vector;
import javax.swing.DefaultListSelectionModel;
import javax.swing.event.EventListenerList;
import javax.swing.event.SwingPropertyChangeSupport;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;

public class DefaultTreeSelectionModel implements Cloneable, Serializable, TreeSelectionModel {
   public static final String SELECTION_MODE_PROPERTY = "selectionMode";
   protected SwingPropertyChangeSupport changeSupport;
   protected TreePath[] selection;
   protected EventListenerList listenerList = new EventListenerList();
   protected transient RowMapper rowMapper;
   protected DefaultListSelectionModel listSelectionModel = new DefaultListSelectionModel();
   protected int selectionMode = 4;
   protected TreePath leadPath;
   protected int leadIndex;
   protected int leadRow;
   // $FF: synthetic field
   static Class class$javax$swing$event$TreeSelectionListener;

   public DefaultTreeSelectionModel() {
      this.leadIndex = this.leadRow = -1;
   }

   public synchronized void addPropertyChangeListener(PropertyChangeListener var1) {
      if (this.changeSupport == null) {
         this.changeSupport = new SwingPropertyChangeSupport(this);
      }

      this.changeSupport.addPropertyChangeListener(var1);
   }

   public void addSelectionPath(TreePath var1) {
      if (var1 != null) {
         TreePath[] var2 = new TreePath[]{var1};
         this.addSelectionPaths(var2);
      }

   }

   public void addSelectionPaths(TreePath[] var1) {
      int var2 = var1 == null ? 0 : var1.length;
      if (var2 > 0) {
         if (this.selectionMode == 1 && this.selection != null && this.selection.length > 0) {
            this.setSelectionPaths(var1);
         } else if (this.selectionMode == 2 && !this.canPathsBeAdded(var1)) {
            if (this.arePathsContiguous(var1)) {
               this.setSelectionPaths(var1);
            } else {
               TreePath[] var13 = new TreePath[]{var1[0]};
               this.setSelectionPaths(var13);
            }
         } else {
            TreePath var9 = this.leadPath;
            Vector var10 = null;
            int var7;
            if (this.selection == null) {
               var7 = 0;
            } else {
               var7 = this.selection.length;
            }

            boolean var3 = false;
            this.leadPath = null;
            int var5 = 0;

            int var6;
            for(var6 = 0; var5 < var1.length; ++var5) {
               if (var1[var5] != null) {
                  boolean var4 = false;

                  for(int var8 = 0; var8 < var7; ++var8) {
                     if (var1[var5].equals(this.selection[var8])) {
                        var8 = var7;
                        if (!var3) {
                           TreePath[] var11 = new TreePath[var1.length];
                           System.arraycopy(var1, 0, var11, 0, var1.length);
                           var1 = var11;
                           var3 = true;
                        }

                        var1[var5] = null;
                        var4 = true;
                     }
                  }

                  if (!var4) {
                     ++var6;
                     if (var10 == null) {
                        var10 = new Vector();
                     }

                     var10.addElement(new PathPlaceHolder(var1[var5], true));
                  }

                  if (this.leadPath == null) {
                     this.leadPath = var1[var5];
                  }
               }
            }

            if (this.leadPath == null) {
               this.leadPath = var9;
            }

            if (var6 > 0) {
               TreePath[] var15 = new TreePath[var7 + var6];
               if (var7 > 0) {
                  System.arraycopy(this.selection, 0, var15, 0, var7);
               }

               if (var6 != var1.length) {
                  int var12 = 0;

                  for(int var14 = 0; var14 < var1.length; ++var14) {
                     if (var1[var14] != null) {
                        var15[var7 + var12++] = var1[var14];
                     }
                  }
               } else {
                  System.arraycopy(var1, 0, var15, var7, var6);
               }

               this.selection = var15;
               this.insureUniqueness();
               this.updateLeadIndex();
               this.resetRowSelection();
               this.notifyPathChange(var10, var9);
            } else {
               this.leadPath = var9;
            }
         }
      }

   }

   public void addTreeSelectionListener(TreeSelectionListener var1) {
      this.listenerList.add(class$javax$swing$event$TreeSelectionListener != null ? class$javax$swing$event$TreeSelectionListener : (class$javax$swing$event$TreeSelectionListener = class$("javax.swing.event.TreeSelectionListener")), var1);
   }

   protected boolean arePathsContiguous(TreePath[] var1) {
      if (this.rowMapper != null && var1.length >= 2) {
         BitSet var2 = new BitSet(32);
         int var6 = var1.length;
         int var7 = 0;
         TreePath[] var8 = new TreePath[]{var1[0]};
         int var5 = this.rowMapper.getRowsForPaths(var8)[0];

         for(int var4 = 0; var4 < var6; ++var4) {
            if (var1[var4] != null) {
               var8[0] = var1[var4];
               int var3 = this.rowMapper.getRowsForPaths(var8)[0];
               if (var3 == -1 || var3 < var5 - var6 || var3 > var5 + var6) {
                  return false;
               }

               if (var3 < var5) {
                  var5 = var3;
               }

               if (!var2.get(var3)) {
                  var2.set(var3);
                  ++var7;
               }
            }
         }

         int var9 = var7 + var5;

         for(int var10 = var5; var10 < var9; ++var10) {
            if (!var2.get(var10)) {
               return false;
            }
         }

         return true;
      } else {
         return true;
      }
   }

   protected boolean canPathsBeAdded(TreePath[] var1) {
      if (var1 != null && var1.length != 0 && this.rowMapper != null && this.selection != null && this.selectionMode != 4) {
         BitSet var2 = new BitSet();
         DefaultListSelectionModel var3 = this.listSelectionModel;
         int var6 = var3.getMinSelectionIndex();
         int var7 = var3.getMaxSelectionIndex();
         TreePath[] var8 = new TreePath[1];
         if (var6 != -1) {
            for(int var5 = var6; var5 <= var7; ++var5) {
               if (var3.isSelectedIndex(var6)) {
                  var2.set(var5);
               }
            }
         } else {
            var8[0] = var1[0];
            var6 = var7 = this.rowMapper.getRowsForPaths(var8)[0];
         }

         for(int var9 = var1.length - 1; var9 >= 0; --var9) {
            if (var1[var9] != null) {
               var8[0] = var1[var9];
               int var4 = this.rowMapper.getRowsForPaths(var8)[0];
               var6 = Math.min(var4, var6);
               var7 = Math.max(var4, var7);
               if (var4 == -1) {
                  return false;
               }

               var2.set(var4);
            }
         }

         for(int var10 = var6; var10 <= var7; ++var10) {
            if (!var2.get(var10)) {
               return false;
            }
         }

         return true;
      } else {
         return true;
      }
   }

   protected boolean canPathsBeRemoved(TreePath[] var1) {
      if (this.rowMapper != null && this.selection != null && this.selectionMode != 4) {
         BitSet var3 = new BitSet();
         int var6 = var1.length;
         int var8 = -1;
         int var9 = 0;
         TreePath[] var10 = new TreePath[var6];
         TreePath[] var11 = new TreePath[1];
         System.arraycopy(var1, 0, var10, 0, var6);

         for(int var4 = this.selection.length - 1; var4 >= 0; --var4) {
            boolean var2 = false;

            for(int var5 = 0; var5 < var6; ++var5) {
               if (var10[var5] != null && this.selection[var4].equals(var10[var5])) {
                  var10[var5] = null;
                  var2 = true;
                  break;
               }
            }

            if (!var2) {
               var11[0] = this.selection[var4];
               int var7 = this.rowMapper.getRowsForPaths(var11)[0];
               if (var7 != -1 && !var3.get(var7)) {
                  ++var9;
                  if (var8 == -1) {
                     var8 = var7;
                  } else {
                     var8 = Math.min(var8, var7);
                  }

                  var3.set(var7);
               }
            }
         }

         if (var9 > 1) {
            for(int var12 = var8 + var9 - 1; var12 >= var8; --var12) {
               if (!var3.get(var12)) {
                  return false;
               }
            }
         }

         return true;
      } else {
         return true;
      }
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   public void clearSelection() {
      if (this.selection != null) {
         int var1 = this.selection.length;
         boolean[] var2 = new boolean[var1];

         for(int var3 = 0; var3 < var1; ++var3) {
            var2[var3] = false;
         }

         TreeSelectionEvent var4 = new TreeSelectionEvent(this, this.selection, var2, this.leadPath, (TreePath)null);
         this.leadPath = null;
         this.leadIndex = this.leadRow = -1;
         this.selection = null;
         this.resetRowSelection();
         this.fireValueChanged(var4);
      }

   }

   public Object clone() throws CloneNotSupportedException {
      DefaultTreeSelectionModel var1 = (DefaultTreeSelectionModel)super.clone();
      var1.changeSupport = null;
      if (this.selection != null) {
         int var2 = this.selection.length;
         var1.selection = new TreePath[var2];
         System.arraycopy(this.selection, 0, var1.selection, 0, var2);
      }

      var1.listenerList = new EventListenerList();
      var1.listSelectionModel = (DefaultListSelectionModel)this.listSelectionModel.clone();
      return var1;
   }

   protected void fireValueChanged(TreeSelectionEvent var1) {
      Object[] var2 = this.listenerList.getListenerList();

      for(int var3 = var2.length - 2; var3 >= 0; var3 -= 2) {
         if (var2[var3] == (class$javax$swing$event$TreeSelectionListener != null ? class$javax$swing$event$TreeSelectionListener : (class$javax$swing$event$TreeSelectionListener = class$("javax.swing.event.TreeSelectionListener")))) {
            ((TreeSelectionListener)var2[var3 + 1]).valueChanged(var1);
         }
      }

   }

   public TreePath getLeadSelectionPath() {
      return this.leadPath;
   }

   public int getLeadSelectionRow() {
      return this.leadRow;
   }

   public int getMaxSelectionRow() {
      return this.listSelectionModel.getMaxSelectionIndex();
   }

   public int getMinSelectionRow() {
      return this.listSelectionModel.getMinSelectionIndex();
   }

   public RowMapper getRowMapper() {
      return this.rowMapper;
   }

   public int getSelectionCount() {
      return this.selection == null ? 0 : this.selection.length;
   }

   public int getSelectionMode() {
      return this.selectionMode;
   }

   public TreePath getSelectionPath() {
      return this.selection != null ? this.selection[0] : null;
   }

   public TreePath[] getSelectionPaths() {
      if (this.selection != null) {
         int var1 = this.selection.length;
         TreePath[] var2 = new TreePath[var1];
         System.arraycopy(this.selection, 0, var2, 0, var1);
         return var2;
      } else {
         return null;
      }
   }

   public int[] getSelectionRows() {
      return this.rowMapper != null && this.selection != null ? this.rowMapper.getRowsForPaths(this.selection) : null;
   }

   protected void insureRowContinuity() {
      if (this.selectionMode == 2 && this.selection != null && this.rowMapper != null) {
         DefaultListSelectionModel var1 = this.listSelectionModel;
         int var2 = var1.getMinSelectionIndex();
         if (var2 != -1) {
            int var3 = var2;

            for(int var4 = var1.getMaxSelectionIndex(); var3 <= var4; ++var3) {
               if (!var1.isSelectedIndex(var3)) {
                  if (var3 != var2) {
                     TreePath[] var5 = new TreePath[var3 - var2];
                     System.arraycopy(this.selection, 0, var5, 0, var3 - var2);
                     this.setSelectionPaths(var5);
                     break;
                  }

                  this.clearSelection();
               }
            }
         }
      } else if (this.selectionMode == 1 && this.selection != null && this.selection.length > 1) {
         this.setSelectionPath(this.selection[0]);
      }

   }

   protected void insureUniqueness() {
      int var2 = 0;

      for(int var1 = 0; var1 < this.selection.length; ++var1) {
         if (this.selection[var1] != null) {
            for(int var3 = var1 + 1; var3 < this.selection.length; ++var3) {
               if (this.selection[var3] != null && this.selection[var1].equals(this.selection[var3])) {
                  ++var2;
                  this.selection[var3] = null;
               }
            }
         }
      }

      if (var2 > 0) {
         TreePath[] var4 = new TreePath[this.selection.length - var2];
         int var5 = 0;

         for(int var6 = 0; var5 < this.selection.length; ++var5) {
            if (this.selection[var5] != null) {
               var4[var6++] = this.selection[var5];
            }
         }

         this.selection = var4;
      }

   }

   public boolean isPathSelected(TreePath var1) {
      if (this.selection != null) {
         for(int var2 = 0; var2 < this.selection.length; ++var2) {
            if (this.selection[var2].equals(var1)) {
               return true;
            }
         }
      }

      return false;
   }

   public boolean isRowSelected(int var1) {
      return this.listSelectionModel.isSelectedIndex(var1);
   }

   public boolean isSelectionEmpty() {
      return this.selection == null;
   }

   protected void notifyPathChange(Vector var1, TreePath var2) {
      int var3 = var1.size();
      boolean[] var4 = new boolean[var3];
      TreePath[] var5 = new TreePath[var3];

      for(int var7 = 0; var7 < var3; ++var7) {
         PathPlaceHolder var6 = (PathPlaceHolder)var1.elementAt(var7);
         var4[var7] = var6.isNew;
         var5[var7] = var6.path;
      }

      TreeSelectionEvent var8 = new TreeSelectionEvent(this, var5, var4, var2, this.leadPath);
      this.fireValueChanged(var8);
   }

   private void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      Object[] var2 = var1.readObject();
      if (var2.length > 0 && var2[0].equals("rowMapper")) {
         this.rowMapper = (RowMapper)var2[1];
      }

   }

   public synchronized void removePropertyChangeListener(PropertyChangeListener var1) {
      if (this.changeSupport != null) {
         this.changeSupport.removePropertyChangeListener(var1);
      }
   }

   public void removeSelectionPath(TreePath var1) {
      if (var1 != null) {
         TreePath[] var2 = new TreePath[]{var1};
         this.removeSelectionPaths(var2);
      }

   }

   public void removeSelectionPaths(TreePath[] var1) {
      if (var1 != null && this.selection != null && var1.length > 0) {
         if (!this.canPathsBeRemoved(var1)) {
            this.clearSelection();
         } else {
            boolean var6 = false;
            TreePath var7 = this.leadPath;
            Vector var8 = null;
            int var2 = this.selection.length;

            for(int var5 = 0; var5 < var1.length; ++var5) {
               if (var1[var5] != null) {
                  if (this.leadPath != null && this.leadPath.equals(var1[var5])) {
                     this.leadPath = null;
                  }

                  for(int var3 = 0; var3 < var2; ++var3) {
                     if (var1[var5].equals(this.selection[var3])) {
                        this.selection[var3] = null;
                        var3 = var2;
                        if (var8 == null) {
                           var8 = new Vector(var1.length);
                        }

                        if (!var8.contains(var1[var5])) {
                           var8.addElement(new PathPlaceHolder(var1[var5], false));
                        }
                     }
                  }
               }
            }

            if (var8 != null) {
               int var4 = var8.size();
               if (var4 == this.selection.length) {
                  this.selection = null;
               } else {
                  int var9 = 0;
                  TreePath[] var10 = new TreePath[this.selection.length - var4];

                  for(int var11 = 0; var11 < var2; ++var11) {
                     if (this.selection[var11] != null) {
                        var10[var9++] = this.selection[var11];
                     }
                  }

                  this.selection = var10;
               }

               if (this.leadPath == null && this.selection != null) {
                  this.leadPath = this.selection[0];
               }

               this.updateLeadIndex();
               this.resetRowSelection();
               this.notifyPathChange(var8, var7);
            }
         }
      }

   }

   public void removeTreeSelectionListener(TreeSelectionListener var1) {
      this.listenerList.remove(class$javax$swing$event$TreeSelectionListener != null ? class$javax$swing$event$TreeSelectionListener : (class$javax$swing$event$TreeSelectionListener = class$("javax.swing.event.TreeSelectionListener")), var1);
   }

   public void resetRowSelection() {
      this.listSelectionModel.clearSelection();
      if (this.selection != null && this.rowMapper != null) {
         boolean var2 = false;
         int[] var3 = this.rowMapper.getRowsForPaths(this.selection);
         int var4 = 0;

         for(int var5 = this.selection.length; var4 < var5; ++var4) {
            int var1 = var3[var4];
            if (var1 != -1) {
               this.listSelectionModel.addSelectionInterval(var1, var1);
            }
         }

         if (this.leadIndex != -1) {
            this.leadRow = var3[this.leadIndex];
         }

         this.insureRowContinuity();
      } else {
         this.leadRow = -1;
      }

   }

   public void setRowMapper(RowMapper var1) {
      this.rowMapper = var1;
      this.resetRowSelection();
   }

   public void setSelectionMode(int var1) {
      int var2 = this.selectionMode;
      this.selectionMode = var1;
      if (this.selectionMode != 1 && this.selectionMode != 2 && this.selectionMode != 4) {
         this.selectionMode = 4;
      }

      if (var2 != this.selectionMode && this.changeSupport != null) {
         this.changeSupport.firePropertyChange("selectionMode", new Integer(var2), new Integer(this.selectionMode));
      }

   }

   public void setSelectionPath(TreePath var1) {
      if (var1 == null) {
         this.setSelectionPaths((TreePath[])null);
      } else {
         TreePath[] var2 = new TreePath[]{var1};
         this.setSelectionPaths(var2);
      }

   }

   public void setSelectionPaths(TreePath[] var1) {
      boolean var2 = false;
      TreePath[] var7 = var1;
      int var3;
      if (var1 == null) {
         var3 = 0;
      } else {
         var3 = var1.length;
      }

      int var5;
      if (this.selection == null) {
         var5 = 0;
      } else {
         var5 = this.selection.length;
      }

      if (var3 + var5 != 0) {
         if (this.selectionMode == 1) {
            if (var3 > 1) {
               var7 = new TreePath[]{var1[0]};
               var3 = 1;
            }
         } else if (this.selectionMode == 2 && var3 > 0 && !this.arePathsContiguous(var1)) {
            var7 = new TreePath[]{var1[0]};
            var3 = 1;
         }

         int var9 = 0;
         TreePath var10 = this.leadPath;
         Vector var11 = new Vector(var3 + var5);
         this.leadPath = null;

         for(int var4 = 0; var4 < var3; ++var4) {
            boolean var8 = false;
            if (var7[var4] != null) {
               ++var9;

               for(int var6 = 0; var6 < var5; ++var6) {
                  if (this.selection[var6] != null && this.selection[var6].equals(var7[var4])) {
                     this.selection[var6] = null;
                     var6 = var5;
                     var8 = true;
                  }
               }

               if (!var8) {
                  var11.addElement(new PathPlaceHolder(var7[var4], true));
               }

               if (this.leadPath == null) {
                  this.leadPath = var7[var4];
               }
            }
         }

         for(int var13 = 0; var13 < var5; ++var13) {
            if (this.selection[var13] != null) {
               var11.addElement(new PathPlaceHolder(this.selection[var13], false));
            }
         }

         if (var9 == 0) {
            this.selection = null;
         } else if (var9 != var3) {
            this.selection = new TreePath[var9];
            int var12 = 0;

            for(int var14 = 0; var12 < var3; ++var12) {
               if (var7[var12] != null) {
                  this.selection[var14++] = var7[var12];
               }
            }
         } else {
            this.selection = new TreePath[var7.length];
            System.arraycopy(var7, 0, this.selection, 0, var7.length);
         }

         if (this.selection != null) {
            this.insureUniqueness();
         }

         this.updateLeadIndex();
         this.resetRowSelection();
         if (var11.size() > 0) {
            this.notifyPathChange(var11, var10);
         }
      }

   }

   public String toString() {
      int var1 = this.getSelectionCount();
      StringBuffer var2 = new StringBuffer();
      int[] var3;
      if (this.rowMapper != null) {
         var3 = this.rowMapper.getRowsForPaths(this.selection);
      } else {
         var3 = null;
      }

      var2.append(this.getClass().getName() + " " + this.hashCode() + " [ ");

      for(int var4 = 0; var4 < var1; ++var4) {
         if (var3 != null) {
            var2.append(this.selection[var4].toString() + "@" + Integer.toString(var3[var4]) + " ");
         } else {
            var2.append(this.selection[var4].toString() + " ");
         }
      }

      var2.append("]");
      return var2.toString();
   }

   protected void updateLeadIndex() {
      if (this.leadPath != null) {
         if (this.selection == null) {
            this.leadPath = null;
            this.leadIndex = this.leadRow = -1;
         } else {
            this.leadRow = this.leadIndex = -1;

            for(int var1 = this.selection.length - 1; var1 >= 0; --var1) {
               if (this.selection[var1].equals(this.leadPath)) {
                  this.leadIndex = var1;
                  break;
               }
            }
         }
      }

   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      Object[] var2;
      if (this.rowMapper != null && this.rowMapper instanceof Serializable) {
         var2 = new Object[]{"rowMapper", this.rowMapper};
      } else {
         var2 = new Object[0];
      }

      var1.writeObject(var2);
   }
}
